---
vid: KHV027
title: Kubectl Vulnerable To CVE-2019-11246
categories: [Remote Code Execution]
---

# {{ page.vid }} - {{ page.title }}

## Issue description

Kubectl is found to be vulnerable to CVE-2019-11246. Please see the Vulnerability description for additional information.

## Remediation

Please see the Vulnerability description for remediation.

## References

- [CVE-2019-11246: Another kubectl Path Traversal Vulnerability Disclosed](https://blog.aquasec.com/kubernetes-security-kubectl-cve-2019-11246)
